@@ -23,7 +23,7 @@ use strict;
 use warnings;
 
 package DUCK;
-my $VERSION        = '0.13.5';
+my $VERSION        = '0.14.0';
 my $COPYRIGHT_YEAR = '2017';
 my $default_user_agent = 'Mozilla/5.0 (X11; Linux x86_64; rv:46.0) '
     . 'Gecko/20100101 Firefox/46.0';
@@ -448,7 +448,7 @@ sub __run_browser {
 
     $curl->setopt(CURLOPT_HEADER, 0);
 
-    if ($cli_options->{'no-check-certificate'} eq 1) {
+    if ($cli_options->{'no-check-certificate'} == 1) {
         $curl->setopt(CURLOPT_SSL_VERIFYPEER, 0);
         $curl->setopt(CURLOPT_SSL_VERIFYHOST, 0);
     }
@@ -576,16 +576,19 @@ sub __run_browser {
         if ($whitelisted == 0 && $response_body) {
             $response_body = strip_html_comments($response_body);
 
+            my $matches = 0;
+
             foreach my $regex (@$website_moved_regexs) {
                 if ($response_body =~ m/\b$regex\b/i) {
                     $disp = 2;
                     $response .= "Website seems to be outdated, "
                         . "is probably a parked domain or for sale. "
                         . "Please update your links!\n"
-                        . "Matching regular expression: m/\\b"
-                        . $regex . "\\b/i";
+                        . "Matching regular expression(s):\n"
+                        if $matches == 0;
+                    $response .= " m/\\b" . $regex . "\\b/i\n";
                     $certainty = "wild-guess";
-                    last;
+                    $matches++;
                 }
             }
         }
